@@ -7,8 +7,9 @@ from termcolor import colored
 import f61d.LOGO as LOGO
 #from f61d.__version__ import *
 from math import ceil
+from tqdm import *
 
-VERSION = (0,2,7)
+VERSION = (0,2,9)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -119,7 +120,9 @@ def Nim():
 
 
 def timeit(fun):
-    
+    '''
+计算你的函数运行时间
+'''
     def wrapper(*args,**kwargs):
         
         t1 = time.time()
@@ -131,11 +134,13 @@ def timeit(fun):
     return wrapper
 
 
-def prove(cont):
+def prove(cont,process_bar=True,show_description=False):
     '''
     Only the format is supported
     sha256(XXXX + {a}) = {b}
     '''
+    if process_bar and show_description:
+        print("Open tqdm bar and description may be VERY SLOW.\nDescription is not sugested.")
     from itertools import product
     import re
     from string import ascii_letters,digits
@@ -144,22 +149,30 @@ def prove(cont):
     
     cont = cont.replace(' ','')
     #print(cont)
-    p = re.compile('sha256(.*?)=(.*)')
+    p = re.compile('sha256(.*?)==(.*)')
     #print(p.findall(cont)[0])
-    r = p.findall(cont)[0]
+    try:
+        r = p.findall(cont)[0]
+    except:
+        print('Failed to parse text.')
+        return
     L = len(r[0].split('+')[0])-1
     a = r[0].split('+')[1][:-1]
     b = r[1]
     print(f"Proving:\n\tsha256({'X'*L} + {a}) = {b}\n")
     s = list(product(ascii_letters+digits,repeat=L))
-    bar = tqdm(s)
+    if process_bar:bar = tqdm(s)
+    else:bar = s
     ss = lambda d:sha256(d.encode()).hexdigest()
     for i in bar:
         S = ''.join(i)
-        bar.set_description(f"trying: {S}")
+        if process_bar and show_description:bar.set_description(f"trying: {S}")
         if ss(S+a) == b:
-            print('Find ,',S)
+            print('\nFind ,',S)
             return S
+    else:
+        print('Failed to find \'XXXX\'')
+        return None
 
     
 def getLogo():
@@ -171,11 +184,3 @@ def yinyang():
     f61d.yinyang.main()
     
     
-def main():
-    Help()
-    fuckStar()
-    #r = prove('sha256(XXX + O3) = a289ace0c0301fba709365606da60acf11d793869a7c76083cef6c1ac6ff1396')
-    #print(r)
-
-if __name__ == '__main__':
-    main()
